#
# spec file for package ghc-hslua-core
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name hslua-core
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        2.2.1
Release:        150500.1.1
Summary:        Bindings to Lua, an embeddable scripting language
License:        MIT
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-exceptions-devel
BuildRequires:  ghc-lua-devel
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-text-devel
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-lua-arbitrary-devel
BuildRequires:  ghc-quickcheck-instances-devel
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-hunit-devel
BuildRequires:  ghc-tasty-quickcheck-devel
%endif

%description
Wrappers and helpers to bridge Haskell and <https://www.lua.org/ Lua>.

It builds upon the /lua/ package, which allows to bundle a Lua interpreter with
a Haskell program.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md README.md

%changelog
* Sun Jun 19 2022 psimons@suse.com
- Update hslua-core to version 2.2.1.
  [#]# hslua-core-2.2.1
  Released 2022-06-19.
  - Ensure that loadfile works with umlauts in filepath: The OS
    does not necessarily expect filenames to be UTF-8 encoded,
    especially Windows. On non-Windows systems, the current file
    system encoding is now used to convert filenames to C
    strings. On Windows, the `CP_ACP` codepage is used, as
    required by the Windows API.
  - GC managed Lua state: Add new type `GCManagedState` and
    functions `newGCManagedState`, `closeGCManagedState`, and
    `withGCManagedState`. These allow to create and use a Lua
    state in flexible ways in that it does not require the state
    to be closed explicitly. The state will be closed when the
    respective variable is collected.
  - Require lua-2.2.1.
  - Relax upper bound for mtl, allow mtl-2.3.
* Sat Feb 19 2022 psimons@suse.com
- Update hslua-core to version 2.2.0.
  [#]# hslua-core-2.2.0
  Released 2022-02-19.
  - Use lua-2.2.0, which requires Lua 5.4.
  - Rename `newuserdata` to `newuserdatauv` and let it take the
    number of associated uservalues as an additional argument.
    Similarly, `newhsuserdata` is now `newhsuserdatauv`.
  - Rename `getuservalue` and `setuservalue` to `getiuservalue`
    and `setiuservalue`, respectively. Like both functions now
    take an extra argument specifying the number of the uservalue
    that should be retrieved or set.
    It is now possible for `setiuservalue` to fail, so it returns
    a boolean to indicate whether the action was successful.
  - The `GCControl` type has been updated to match the new gc
    control:
  - The GCStep constructor takes an argument "stepsize";
  - constructors GCGen and GCInc have been added;
  - constructors GCSetPause and GCSetStepMul have been removed.
* Sat Jan 29 2022 psimons@suse.com
- Update hslua-core to version 2.1.0.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/hslua-core-2.1.0/src/CHANGELOG.md
* Thu Nov  4 2021 psimons@suse.com
- Update hslua-core to version 2.0.0.2.
  [#]# hslua-core 2.0.0.2
  Released 2021-11-03.
  - Fixed output of `pushTypeMismatchError` when there is no value
    at the given index. Previously the function would report the
    value as type `string` and now reports it as `no value`.
* Mon Nov  1 2021 psimons@suse.com
- Add hslua-core at version 2.0.0.1.
